@@ -95,6 +95,13 @@ void debug_test_minimal_recording(int different_way) {
 
 void chum_start_chum(int argc, char** argv){
     int i;
+    #ifdef N900
+    gchar *cmd = g_strdup_printf("mkdir -p /home/user/.jammo");
+    int error_code = system(cmd);
+    if (error_code)
+        printf("Error, can't call '%s'\n",cmd);
+    #endif
+    
     cem_add_to_log("chum_start_chum()",LOG_DEBUG);
     for (i=1;i<argc;i++) 
       {
@@ -147,9 +154,10 @@ void chum_start_chum(int argc, char** argv){
 
     chum_start_jammo_main_loop();
 }
+char *name_of_states[] = {"SCREEN_WELCOME","SCREEN_GAME_SELECTION","SCREEN_THEME_SELECTION","SCREEN_COMPOSING","SCREEN_SONG_SELECTION","SCREEN_SONG_RECORDING","SCREEN_PLAY_RECORDED","SCREEN_PLAY_RECORDED","SCREEN_MIDI_EDITOR"};
 
 void chum_go_back() {
-    cem_add_to_log(g_strdup_printf("chum_go_back(). state_of_chum was %d...",state_of_chum),LOG_DEBUG);
+    cem_add_to_log(g_strdup_printf("chum_go_back(). state_of_chum was %s...",name_of_states[state_of_chum]),LOG_DEBUG);
 
     switch (chum_get_state_of_chum()) {
       //singing
@@ -160,7 +168,9 @@ void chum_go_back() {
 	  state_of_chum=SCREEN_SONG_SELECTION;
 	  break;
       case SCREEN_PLAY_RECORDED:
-	  state_of_chum=SCREEN_SONG_RECORDING;
+	  //state_of_chum=SCREEN_SONG_RECORDING;
+          chum_stop_sequencer();
+          chum_change_to_song(chum_get_current_song());
 	  break;
 
       //composing
@@ -173,14 +183,14 @@ void chum_go_back() {
       }
 
 
-    cem_add_to_log(g_strdup_printf("...chum_go_back(). new state_of_chum is %d",state_of_chum),LOG_DEBUG);
+    cem_add_to_log(g_strdup_printf("...chum_go_back(). new state_of_chum is %s",name_of_states[state_of_chum]),LOG_DEBUG);
 
     gui_go_screen(state_of_chum);
 }
 
 
 void chum_go_next() {
-    cem_add_to_log(g_strdup_printf("chum_go_next(). state_of_chum was %d...",state_of_chum),LOG_DEBUG);
+    cem_add_to_log(g_strdup_printf("chum_go_next(). state_of_chum was %s...",name_of_states[state_of_chum]),LOG_DEBUG);
 
     //singing game is handled with switch-case. Composing game doens't have such a thing like next.
     switch (chum_get_state_of_chum()) {
@@ -197,13 +207,13 @@ void chum_go_next() {
 	break;
     }
 
-    cem_add_to_log(g_strdup_printf("...chum_go_next(). new state_of_chum is %d",state_of_chum),LOG_DEBUG);
+    cem_add_to_log(g_strdup_printf("...chum_go_next(). new state_of_chum is %s",name_of_states[state_of_chum]),LOG_DEBUG);
 
     gui_go_screen(state_of_chum);
 }
 
 void chum_go_screen(int screen_number){
-    cem_add_to_log(g_strdup_printf("chum_go_screen(%d)",screen_number),LOG_DEBUG);
+    cem_add_to_log(g_strdup_printf("chum_go_screen(%s)",name_of_states[screen_number]),LOG_DEBUG);
     state_of_chum=screen_number;
     gui_go_screen(state_of_chum);
 }
@@ -251,9 +261,10 @@ chum_change_theme(theme_number);
 /* If this is needed, it should be moved to track.c or pipeline.c
 It doesn't call free_track, so it can waste memory */
 void remove_track (Track *trc){
-printf("remove_track begin\n");
+printf("chum: remove_track begin\n");
 get_mainPipeline()->tracks =  g_list_remove(get_mainPipeline()->tracks, trc);
 	gst_bin_remove(GST_BIN(get_mainPipeline()->pipeline), trc->trackbin);
+free_track(trc);
 }
 
 int chum_get_current_song(){
@@ -302,7 +313,6 @@ void chum_change_to_song(int song_number){
 
     create_new_singing_track();
     state_of_chum=SCREEN_SONG_RECORDING;
-    gui_go_screen(state_of_chum);
 }
 
 void chum_play_one_sample(char* filename){
