@@ -41,6 +41,7 @@ chum_get_all_slot_info(0);
 
 void do_back_button_press(){
   chum_stop_sequencer();
+  chum_stop_one_sample();
   chum_go_back();
 }
 
@@ -155,7 +156,7 @@ ClutterActor* button_create_theme_selection_button (){
     //first make image taller and then clip from bottom
 
     clutter_actor_set_height (actor,700);
-    clutter_actor_set_clip (actor,800/number_of_themes,0,800/number_of_themes,480);
+    clutter_actor_set_clip (actor,WIDTH_OF_WINDOW/number_of_themes,0,WIDTH_OF_WINDOW/number_of_themes,HEIGHT_OF_WINDOW);
     clutter_actor_set_scale (actor,0.1,0.1);
 
     clutter_actor_set_position (actor,80/number_of_themes*(i-2),0);		
@@ -187,7 +188,7 @@ ClutterActor* button_create_theme_selection_button (){
 
 
   clutter_actor_set_position (objects_group,700,5);
-
+  clutter_actor_set_name(objects_group, "back button");
   return objects_group;
 }
 
@@ -207,6 +208,7 @@ void button_create_buttons (ClutterActor* objects_group) {
 		actor = config_get_configured_actor(NULL,buffer);
 		
 		clutter_container_add_actor(CLUTTER_CONTAINER(objects_group), actor);
+                g_signal_connect (actor, "button-press-event", G_CALLBACK (button_mouse_behaviour),NULL);  
 		clutter_actor_set_reactive(actor, TRUE);
 	}
 
