@@ -21,11 +21,13 @@ ClutterColor *get_blue_color();
 ClutterActor* load_background(const char* theme_folder);
 ClutterActor* get_drop_area();
 ClutterActor* main_getStage();
+
 void show_game_selection();
+void gui_visualize_playing(int state);
 
 typedef struct ActorBehaviour {
 	ClutterActor* actor;
 	ClutterBehaviour* behaviour;
 } ActorBehaviour;
 
-#endif /* CLUTTER_JAMMO_H */
+#endif /* _CLUTTER_JAMMO_H_ */
