@@ -143,7 +143,7 @@ void stage_start_behaviour(ClutterActor* actor, ClutterBehaviour* behaviour)
  */
 ClutterActor* load_background(const char* theme_folder)
 {
-	ClutterActor* actor = clutter_texture_new ();;
+	ClutterActor* actor = clutter_texture_new ();
 	gchar* filepath1;
 	gchar* dir = THEMES_DIR;
 	filepath1 = g_strdup_printf("%s/%s/background.png", dir, theme_folder);
@@ -270,7 +270,7 @@ chum_go_screen(SCREEN_COMPOSING);
 
 
 static void from_theme_selection_to_game_selection(){
-chum_go_back();
+chum_go_screen(SCREEN_GAME_SELECTION);
 }
 
 GList *group; /*There are variable number of themes and border lines.*/
