@@ -58,6 +58,7 @@ return;
   }
 }
 
+#ifdef BEHAVIOURS_DISABLED
 /*When we want stop behaviour, we add signal to timeline which triggers when frame 1 starts.
 Then this function is called and we stop behaviour for this actor.*/
 static void start_of_loop(ClutterTimeline *timeline,  gchar *name, gint frame, gpointer data) {
@@ -71,7 +72,7 @@ clutter_timeline_remove_marker(timeline,name);
 
     clutter_behaviour_remove (behaviour,actor);
 }
-
+#endif
 
 /*
 Use this function when actor is placed in valid-area.
@@ -80,9 +81,7 @@ This handles only places of graphical actors, not sound samples.
 void put_in_timeline(JammoTexture *dropped_actor, gint release_x)  {
 //This new will take asked place.
 clutter_actor_set_position (CLUTTER_ACTOR(dropped_actor), release_x, Y_PLACE_OF_TIMELINE);
-
 gint width_of_new=clutter_actor_get_width(CLUTTER_ACTOR(dropped_actor));
-
 //if this doesn't fit, we can remove graphical object now. sound is already handled.
 if (width_of_new+release_x>WIDTH_OF_WINDOW) {
     clutter_container_remove_actor(CLUTTER_CONTAINER(clutter_actor_get_parent(CLUTTER_ACTOR(dropped_actor))), CLUTTER_ACTOR(dropped_actor));
@@ -94,11 +93,42 @@ int slots_of_new= width_of_new / WIDTH_OF_SLOT; //how many slot this takes.
 int i,j;
 
   //Loop over all actors
+  GList* children = composing_game_get_actors_in_track();
+  GList *l;
+  for (l = children; l; l = l->next){
+    JammoTexture *actor = l->data;
+    gchar *name = clutter_actor_get_name(CLUTTER_ACTOR(actor)); //This gives warning!
+    printf ("name is %s\n",name);
+       gfloat x0_f,y0_f;
+       clutter_actor_get_position (CLUTTER_ACTOR(actor),&x0_f,&y0_f);
+       //objects coordinates:
+       gint x0=(gint)x0_f;
+       //gint y0=(gint)y0_f; //not used yet.
+       //we not interested in current_actor
+       if ( actor != dropped_actor){
+             //printf("x=%d, y=%d\n",x0,y0);
+             gint x0_width=clutter_actor_get_width(CLUTTER_ACTOR(actor));
+             gint x0_slots=x0_width/ WIDTH_OF_SLOT;
+             for (i=0;i<slots_of_new;i++) {
+                  for (j=0;j<x0_slots;j++) {
+                      //check if new actor has any common slots with this
+                      if ((x0+j*WIDTH_OF_SLOT==release_x+i*WIDTH_OF_SLOT)) { 
+                          //move it too
+                          put_in_timeline(actor,x0+(slots_of_new-i+j)*WIDTH_OF_SLOT);
+                          //break;
+                      }
+                  }
+            }
+      }
+  }
+  /*
   ClutterActor *stage=clutter_actor_get_parent(CLUTTER_ACTOR(dropped_actor));
   GList* children= clutter_container_get_children (CLUTTER_CONTAINER (stage));
   GList *l;
   for (l = children; l; l = l->next){
     JammoTexture *actor = l->data;
+    gchar *name = clutter_actor_get_name(actor);
+    printf ("name is %s\n",name);
        gfloat x0_f,y0_f;
        clutter_actor_get_position (CLUTTER_ACTOR(actor),&x0_f,&y0_f);
        gint x0=(gint)x0_f,y0=(gint)y0_f; //objects coordinates
@@ -118,7 +148,7 @@ int i,j;
 		  }
 	    }
       }
-  }
+  }*/
 
 }
 
@@ -131,24 +161,23 @@ void object_add_to_timeline(JammoTexture *dropped_actor, gint release_x,gint suk
 int slot_number = release_x / WIDTH_OF_SLOT;
 gint icon_place_of_dropped = slot_number*WIDTH_OF_SLOT;   //this is x coordinate of dropped
 
+GList *actors_in_track  = composing_game_get_actors_in_track();
+actors_in_track  = g_list_append(actors_in_track,  CLUTTER_ACTOR (dropped_actor));
+
+
 printf ("slot number %d\n",slot_number);
 put_in_timeline(dropped_actor,icon_place_of_dropped);
-
 //Put sound
-
  gchar *sound;
   g_object_get(G_OBJECT(dropped_actor), "sound-file", &sound, NULL);
-
   gchar* buffer0;
   buffer0 = g_strdup_printf("%s/themes/%s/%s",DATA_DIR,chum_get_theme_folder(chum_get_current_theme()), sound);
-
   chum_add_new_sample_to_track_nth_slot(0,buffer0,slot_number);
-
+#ifdef ALL_BEHAVING_ARE_DISABLED_TEMPORARILY
 //stop behaving
   GList *behaviours_and_actors = get_current_behaviours_and_actors();
   GList *l_counter;
   int counter=0;
-
   for (l_counter = behaviours_and_actors; l_counter; l_counter = l_counter->next){
     counter++;
     ActorBehaviour *ab = l_counter->data;
@@ -172,6 +201,7 @@ put_in_timeline(dropped_actor,icon_place_of_dropped);
     }
     else printf("not\n");
   }
+#endif
 
 }
 
