@@ -8,8 +8,6 @@ License: GPLv2, read more from COPYING
 #include "sequencer/sequencer.h"
 
 void meam_init();
-void meam_start_gstreamer_loop();
-GMainLoop *meam_get_main_loop();
 
 void meam_seq_stop();
 void meam_seq_play();
@@ -39,7 +37,7 @@ void meam_get_duration_of_song(guint64 *value);
 
 void meam_slider_state(gboolean b);
 void meam_slider_freq(int a);
-
+void meam_create_new_empty_track();
 
 guint meam_get_meter_of_track(int track_number);
 guint meam_get_tempo_of_track(int track_number);
