@@ -45,7 +45,7 @@ gboolean pipeline_init(void)
 
 		gst_element_link(mainPipeline->adder, mainPipeline->audiosink);
 	  	if(GST_PAD_LINK_SUCCESSFUL(GST_PAD_LINK_OK))
-	    		g_print("Linking successfully completed (Adder -> Sink)\n");
+                        {} //g_print("Linking successfully completed (Adder -> Sink)\n");
 	  	else 
 	    		g_print("Linking failed! (Adder -> Sink)\n");
 
@@ -73,7 +73,7 @@ void free_pipeline(void)
 	// Frees mainPipeline
 	free(mainPipeline);
 	mainPipeline = NULL;
-	g_print("Pipeline - allocated memory freed\nNow closing program...\n");
+	g_print("Pipeline - allocated memory freed\n");
 }
 
 /**
