@@ -41,6 +41,7 @@ Track *create_new_empty_track(void)
 	Track *trc = (Track*) malloc(sizeof(Track));
 	if(trc != NULL)
 	{
+                trc->type = TRACK_SAMPLES;
 		int track_number = g_list_length(get_mainPipeline()->tracks)+1;
 		gchar track_nbr[10];
 		gchar composition_nbr[16];
@@ -146,6 +147,7 @@ Track *create_new_backing_track(gchar *filename)
   Track *trc = (Track*) malloc(sizeof(Track));
   if(trc != NULL)
   {
+    trc->type = TRACK_BACKINGTRACK;
     GstElement  *convert, *source1;
 
     /*track 1 uses these */
@@ -188,6 +190,7 @@ void create_new_singing_track(void)
 	Track *trc = (Track*) malloc(sizeof(Track));
 	if(trc != NULL)
 	{	
+                trc->type = TRACK_SINGING;
 		int track_number = g_list_length(get_mainPipeline()->tracks)+1;
 		gchar track_nbr[10];
 		GstElement *source;
@@ -299,6 +302,7 @@ Track *create_instrument_track(gint instrument_nro)
 	Track *trc = (Track*) malloc(sizeof(Track));
 	if(trc != NULL)
 	{	
+                trc->type = TRACK_INSTRUMENT;
 		int track_number = g_list_length(get_mainPipeline()->tracks)+1;
 		gchar track_nbr[10];
 		gchar composition_nbr[16];
@@ -583,14 +587,19 @@ void remove_samples_from_track(guint track_number)
 
 	if(pipeline->tracks != NULL) {
 			Track *trc = g_list_nth_data(pipeline->tracks, track_number);
+                        if (trc != NULL)
+                        {
 			g_print("Track: %s\n", gst_element_get_name(trc->trackbin));
 
-			//empty all slot_infos
-			gint i;
-			for (i=0;i<SLOT_LIMIT;i++) {
-			    trc->slot_info[i]->info=0;
-			    trc->slot_info[i]->sample=NULL;
-			   }
+                        gint i;
+			//empty all slot_infos (not all track type has slot_info)
+                        if (trc->type == TRACK_SAMPLES)
+                          {
+                          for (i=0;i<SLOT_LIMIT;i++) {
+                                trc->slot_info[i]->info=0;
+                                trc->slot_info[i]->sample=NULL;
+                            }
+                          }
 
 			if(g_list_length(trc->samples) != 0) {
 				g_list_foreach(trc->samples, (GFunc)remove_sample_from_track, NULL);
@@ -608,6 +617,6 @@ void remove_samples_from_track(guint track_number)
 			}
 		pipeline->pipelines_end_time = biggest;
 		}
-	
+        }
  }
 
