@@ -53,8 +53,17 @@ typedef struct SlotInfo {
 	struct Sample *sample;
 } SlotInfo;
 
+// Type of track
+enum {
+  TRACK_SAMPLES,
+  TRACK_BACKINGTRACK,
+  TRACK_INSTRUMENT,
+  TRACK_SINGING,
+};
+
 // Struct definition
 typedef struct Track {
+  gint type;
   GstElement *trackbin;		   /*This is container of all tracks elements*/
   GstElement *composition; 	   /* Samples are added here (only sample-tracks use this)*/
   guint tempo; /* beats per minute (e.g. 130) (only sample-tracks use this) */
@@ -69,7 +78,6 @@ typedef struct Track {
 	GstElement *volume;		/*Volume of this track.*/
 } Track;
 
-
 // Function prototypes
 Track *create_new_empty_track(void);
 Track *create_instrument_track(gint instrument_nro);
